/**
 * SPDX-FileCopyrightText: 2021-2025 EasyCoding Team and contributors
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
*/

#ifndef APPSTRINGS_H
#define APPSTRINGS_H

/**
 * @file appconstants/appconstants.h
 * This file contains AppConstants namespace.
*/

#include <QString>

/**
 * Namespace for working with various constants used in project.
*/
namespace AppConstants {
    /**
     * Stores the application company name.
     * Used as a settings directory name.
    */
    const QString ProductCompany = QStringLiteral("EasyCoding");

    /**
     * Stores the application public name.
     * Used as a public name in various dialogs.
    */
    const QString ProductName = QStringLiteral("Tuned Switcher");

    /**
     * Stores the application internal name.
     * Used as a settings project name.
    */
    const QString ProductNameInternal = QStringLiteral("tuned-switcher");

    /**
     * Stores the application version number as a string.
    */
    const QString ProductVersion = QStringLiteral("0.8.1");

    /**
     * Stores the application launcher file name without the .desktop extension.
    */
    const QString LauncherName = QStringLiteral("org.easycoding.TunedSwitcher");

    /**
     * Stores the application reverse domain scheme name.
    */
    const QString DomainSchemeName = QStringLiteral("org.easycoding.TunedSwitcher");

    /**
     * Stores the data root directory installation prefix.
    */
    const QString DataRootPrefix = QStringLiteral("/usr/share/");

    /**
     * Stores the default application sleep time before trying to
     * fetch the available performance profiles.
    */
    const int SleepTime = 2;

    /**
     * Stores the default timer delay in milliseconds before attempting
     * to shut down the application.
    */
    const int TimerDelay = 2;
}

#endif // APPSTRINGS_H
